/*
 * @FilePath: \wwwd:\code\screenFront\src\http\offsite\index.ts
 * @Author: 王路平
 * @文件版本: V1.0.0
 * @Date: 2023-03-06 13:15:36
 * @Description: 
 * 
 * 版权信息         : 2023 by ${再登软件}, All Rights Reserved.
 */
import {get,post} from "@/utils/http"


export function deviceCountsOfOutPlantData(){
    return get('/device/deviceCountsOfOutPlant')
}
export function deviceTypeCountsOfOutPlantData(){
    return get('/device/deviceTypeCountsOfOutPlant')
}
export function deviceStatusCountsOfOutPlantData(){
    return get('/device/deviceStatusCountsOfOutPlant')
}
export function getDeviceOutPlantData(){
    return get('/device/getDeviceOutPlant')
}
// 各分公司设备数量(二级)
export function deviceCountsSecondaryOfOutPlantData(){
    return get('/device/deviceCountsSecondaryOfOutPlant')
}
// 分公司各类型设备数量(二级)
export function deviceTypeCountsSecondaryOfOutPlantData(){
    return get('/device/deviceTypeCountsSecondaryOfOutPlant')
}
// 分公司设备各种状态的数量(二级)
export function deviceStatusCountsSecondaryOfOutPlantData(){
    return get('/device/deviceStatusCountsSecondaryOfOutPlant')
}
// 分公司二级页面列表
export function secondaryOutPlantData(){
    return get('/device/secondaryOutPlant')
}